spBayesSurv-package: Spatial Copula Modelling to Bayesian Survival Analysis
Description
This package provides Bayesian model fitting for several survival models
including spatial copula linear dependent Dirichlet process mixture model,
anova Dirichlet process mixture model, proportional hazards model and marginal spatial proportional hazards model.Details
ll{
Package: spBayesSurv
Type: Package
Version: 1.0.0
Date: 2014-06-10
License: GPL (>= 2)
}
This package provides functions for fitting several Bayesian survival models including
spCopulaDDP for spatial copula linear dependent Dirichlet process mixture model, anovaDDP
for anova Dirichlet process mixture, indeptCoxph for proportional hazards model, and
spCopulaCox for marginal spatial proportional hazards model.References
De Iorio, M., Johnson, W. O., Mueller, P., and Rosner, G. L. (2009). Bayesian nonparametric nonproportional hazards survival modeling.
Biometrics, 65(3), 762-771.
Zhou, H., Hanson, T. and Knapp, R. (2014+). A Spatial Copula Approach to Fully Bayesian Nonparametric Survival Analysis.
In preparation for publication.